@@ -17,7 +17,7 @@ def math_round(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
     if x is None:
         raise macal.RuntimeError('Round requires at least one argument.', func.Token.Location, filename)
     rval = x.GetValue()
-    digits = scope.GetVariable(digits)
+    digits = scope.GetVariable("digits")
     if digits is None:
         scope.SetReturnValue(round(rval))
     else:
