@@ -5,6 +5,7 @@
 
 import sys
 import logging
+import logging.config
 import macal
 
 
@@ -79,11 +80,11 @@ class SysLog:
 		if remote is True:
 			self.remote_enabled = True
 			self.handle         = logging.getLogger('macal-syslog-remote')
-			self.debug          = self.remote.debug
-			self.info           = self.remote.info
-			self.warn           = self.remote.warn
-			self.error          = self.remote.error
-			self.critical       = self.remote.critical
+			self.debug          = self.handle.debug
+			self.info           = self.handle.info
+			self.warn           = self.handle.warn
+			self.error          = self.handle.error
+			self.critical       = self.handle.critical
 		else:
 			self.syslog_enabled = True
 			self.handle   		= logging.getLogger('macal-syslog')
@@ -97,7 +98,7 @@ class SysLog:
 		
 	def SysLogSetAddress(self, address, port):
 		if self.remote_enabled is True or self.syslog_enabled is True:
-			raise macal.RuntimeError("Cannot change configuration, syslog was already initialized!", None, None)
+			raise macal.RuntimeError("Cannot change configuration, syslog was already initialized!", None, '')
 		self.__address__ = address
 		self.__port__ = port
 		logging.config.dictConfig(self.__config__)
@@ -111,15 +112,15 @@ def Syslog(func:macal.FunctionDefinition, scope: macal.Scope, filename: str) ->
     lvl = scope.GetVariable("level")
     level = lvl.GetValue()
     message = scope.GetVariable("message").GetValue()
-    if level == "debug":
+    if level == "debug" and SysLogLocal.debug is not None:
         SysLogLocal.debug(message)
-    elif level == "info" or level == "information":
+    elif (level == "info" or level == "information") and SysLogLocal.info is not None:
         SysLogLocal.info(message)
-    elif level == "warn" or level == "warning":
+    elif (level == "warn" or level == "warning") and SysLogLocal.warn is not None:
         SysLogLocal.warn(message)
-    elif level == "error":
+    elif level == "error" and SysLogLocal.error is not None:
         SysLogLocal.error(message)
-    elif level == "critical":
+    elif level == "critical" and SysLogLocal.critical is not None:
         SysLogLocal.critical(message)
     else:
         raise macal.RuntimeError(f"Invalid syslog level given: {level}", lvl.Token.Location, filename)
