@@ -10,13 +10,14 @@
 from .lexer import Lexer
 from .location import SourceLocation
 from .token import LexToken
-from .types import LexTokenType, LexTokenTypes, AstType, AstTypes, ExprType, ExprTypes, VariableType, VariableTypes
+from .types import LexTokenType, AstType, ExprType, VariableType
 from .parser import Parser
 from .exceptions import RuntimeError, ParserError, LexError
 from .macal import Macal
 from .mscope import Scope
 from .ast_function_definition import FunctionDefinition
 from .value_item import ValueItem
+from .ast_print import PrintAST
 from .__about__ import __author__, __author_email__, __credits__, __version__
 from .interpreter import ValidateFunctionArguments
 
@@ -25,15 +26,11 @@ __all__ = [
     'SourceLocation',
     'LexToken',
     'LexTokenType',
-    'LexTokenTypes',
     'Lexer',    
     'Parser',
     'AstType',
-    'AstTypes',
     'ExprType',
-    'ExprTypes',
     'VariableType',
-    'VariableTypes',
     'RuntimeError',
     'ParserError',
     'LexError',
@@ -45,5 +42,6 @@ __all__ = [
     '__author_email__',
     '__credits__',
     '__version__',
-    'ValidateFunctionArguments'
+    'ValidateFunctionArguments',
+    'PrintAST'
 ]
\ No newline at end of file
