@@ -4,6 +4,7 @@
 # Date:      09-09-2022
 #
 
+from __future__ import annotations
 from . import types
 from . import token
 
@@ -16,6 +17,7 @@ class AST:
 
 
     def __mask_linefeeds__(self, string: str) -> str:
+        """protected function that removes linefeeds from a string"""
         return string.replace('\n', '\\n')
 
 
