@@ -4,6 +4,7 @@
 # Date:      12-09-2022
 #
 
+from __future__ import annotations
 from . import ast
 from . import types
 from . import token
@@ -12,10 +13,10 @@ import typing
 
 class Block(ast.AST):
     def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Block)
-        self.Instructions : typing.List[ast.AST]= []
-
+        super().__init__(tok, types.AstType.Block)
+        self.Instructions : typing.List[ast.AST] = []
 
+    
 
     def Add(self, instruction: ast.AST) -> None:
         self.Instructions.append(instruction)
@@ -28,7 +29,7 @@ class Block(ast.AST):
 
 
     def __repr__(self) -> str:
-        return f"block({{}}), {self.Location}"
+        return f"block({{}}), {self.Token.Location}"
 
 
     def __str__(self) -> str:
