@@ -11,7 +11,7 @@ from . import token
 
 class Break(ast.AST):
     def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Break)
+        super().__init__(tok, types.AstType.Break)
 
 
 
