@@ -12,11 +12,11 @@ from . import token
 
 
 class FunctionCall(ast.AST):
-    def __init__(self, tok: token.LexToken, varIndex: ast_expr.Expr) -> None:
-        super().__init__(tok, types.AstTypes.FunctionCall)
+    def __init__(self, tok: token.LexToken, varIndex: typing.Optional[ast_expr.Expr]) -> None:
+        super().__init__(tok, types.AstType.FunctionCall)
         self.Name = tok.Lexeme
         self.Args: typing.List[ast_expr.Expr]
-        self.VarIndex: ast_expr.Expr = varIndex
+        self.VarIndex: typing.Optional[ast_expr.Expr] = varIndex
 
 
 
