@@ -10,9 +10,9 @@ from . import token
 from . import ast_expr
 
 class Halt(ast.AST):
-    def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Halt)
-        self.Exitcode: ast_expr.Expr = None
+    def __init__(self, tok: token.LexToken, exitcode: ast_expr.Expr) -> None:
+        super().__init__(tok, types.AstType.Halt)
+        self.Exitcode: ast_expr.Expr = exitcode
 
 
 
