@@ -14,9 +14,9 @@ from . import token
 
 class Elif(ast.AST):
     def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Elif)
-        self.Condition: ast_expr.Expr = None
-        self.Block: ast_block.Block = None
+        super().__init__(tok, types.AstType.Elif)
+        self.Condition: typing.Optional[ast_expr.Expr] = None
+        self.Block: typing.Optional[ast_block.Block] = None
 
 
 
@@ -26,11 +26,11 @@ class Elif(ast.AST):
 
 class If(ast.AST):
     def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.If)
-        self.Condition: ast_expr.Expr = None
-        self.Block: ast_block.Block = None
+        super().__init__(tok, types.AstType.If)
+        self.Condition: typing.Optional[ast_expr.Expr] = None
+        self.Block: typing.Optional[ast_block.Block] = None
         self.Elif: typing.List[Elif] = []
-        self.Else: ast_block.Block = None
+        self.Else: typing.Optional[ast_block.Block] = None
 
 
     
