@@ -12,7 +12,7 @@ from . import token
 
 class Include(ast.AST):
     def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Include)
+        super().__init__(tok, types.AstType.Include)
         self.Includes: typing.List[token.LexToken] = []
 
     
