@@ -12,15 +12,15 @@ from . import ast_expr
 from . import ast_select_field
 
 class Select(ast.AST):
-    '''Contains the location in the source code.'''
-    def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.Select)
+    '''select [distinct] <field-list | *> from <expr> [where <expr>] [merge] into <expr>.'''
+    def __init__(self, tok: token.LexToken, frm: ast_expr.Expr, into: ast_expr.Expr) -> None:
+        super().__init__(tok, types.AstType.Select)
         self.Fields: typing.List[ast_select_field.SelectField] = []
+        self.From: ast_expr.Expr = frm
+        self.Into: ast_expr.Expr = into
+        self.Where: typing.Optional[ast_expr.Expr] = None
         self.Distinct: bool = False
-        self.From: ast_expr.Expr = None
-        self.Where: ast_expr.Expr = None
         self.Merge: bool = False
-        self.Into: ast_expr.Expr = None
 
 
 
