@@ -12,10 +12,10 @@ from . import token
 
 
 class While(ast.AST):
-    def __init__(self, tok: token.LexToken) -> None:
-        super().__init__(tok, types.AstTypes.While)
-        self.Condition: ast_expr.Expr = None
-        self.Block: ast_block.Block = None
+    def __init__(self, tok: token.LexToken, condition: ast_expr.Expr, blk: ast_block.Block) -> None:
+        super().__init__(tok, types.AstType.While)
+        self.Condition: ast_expr.Expr = condition
+        self.Block: ast_block.Block = blk
 
 
     def __str__(self):
