@@ -14,6 +14,6 @@ def strRight(func:macal.FunctionDefinition, scope: macal.Scope, filename: str) -
     length = argl.GetValue()
     endpos = len(value)
     start = endpos - length
-    result = scope.RunFunction('mid', scope, arg=arg, start=start, length=length)
+    result = scope.RunFunction('Mid', scope, arg=arg, start=start, length=length)
     scope.SetReturnValue(result)
     
\ No newline at end of file
