@@ -7,7 +7,6 @@
 from __future__ import annotations
 import os
 import pathlib
-import pkg_resources
 import typing
 from . import mscope
 from . import lexer
@@ -19,42 +18,38 @@ from . import variable
 from . import value_item
 from . import ast_function_definition
 from . import token
-from . import location
 
 
 class Macal:
-    def __init__(self, debugParser: bool = False) -> Macal:
-        self.debug: bool = True
-        self.debugParser: bool = debugParser
-        self.scriptExtension: str = 'mcl'
+    def __init__(self) -> None:
+        self.debug: bool = False
+        self.scriptExtension: str = '.mcl'
         self.Root: mscope.Scope = mscope.Scope('root')
         self.Root.Root = self.Root
-        self.exitcode: variable.Variable = self.RegisterVariable("exitcode", 0)
-        self.filePath: str = None
-        fn = self.RegisterEmbeddedFunction('getInfiniteLoopProtectionCount', self.Root)
-        fn.registerArgument(None)
-        fn = self.RegisterEmbeddedFunction('setInfiniteLoopProtectionCount', self.Root)
-        fn.registerArgument('count')
+        self.exitcode: variable.Variable = self.RegisterVariable("exitcode", 0, 'root')
+        self.filePath: str = ''
+        fn = self.RegisterEmbeddedFunction('GetInfiniteLoopProtectionCount', self.Root, 'root')
+        fn.RegisterArgument('')
+        fn = self.RegisterEmbeddedFunction('SetInfiniteLoopProtectionCount', self.Root, 'root')
+        fn.RegisterArgument('count')
 
 
        
-    def RegisterVariable(self, name: str, value: typing.Any) -> variable.Variable:
-        tok = token.LexToken(name, types.LexTokenTypes.Identifier, location.nullLoc(), -1)
+    def RegisterVariable(self, name: str, value: typing.Any, filename: str) -> variable.Variable:
+        tok = token.LexToken(name, types.LexTokenType.Identifier, None, -1, filename)
         var = variable.Variable(tok, name)
-        tok = token.LexToken('?registered_var_value?', types.LexTokenTypes.Identifier, location.nullLoc(), -1)
-        var.Value = value_item.ValueItem().SetFromPython(tok, value)
+        tok = token.LexToken('?registered_var_value?', types.LexTokenType.Identifier, None, -1, filename)
+        var.Value = value_item.ValueItem(tok, types.VariableType.Nil, types.VariableType.Nil.name.lower()).ConvertFromPython(tok, value)
         self.Root.AddVariable(var)
         return var
 
 
 
-    def RegisterEmbeddedFunction(self, name: str, scope: mscope.Scope) -> ast_function_definition.FunctionDefinition:
+    def RegisterEmbeddedFunction(self, name: str, scope: mscope.Scope, filename: str) -> ast_function_definition.FunctionDefinition:
         func = ast_function_definition.FunctionDefinition(
-            token.LexToken(name, types.LexTokenTypes.Identifier, 
-            location.SourceLocation(-1, -1), 
-            -1))
+            token.LexToken(name, types.LexTokenType.Identifier, None, -1, filename))
         func.IsExternal = True
-        scope.Functions.append(func)
+        scope.Functions[func.Name] = func
         return func
 
 
@@ -64,23 +59,19 @@ class Macal:
             with open (filename, mode = 'r', encoding = 'utf-8') as text_file:
                 source = text_file.read()
             return source
-        return None
+        return ''
 
 
 
     def FindIncludeFileName(self, include: str, scope: mscope.Scope) -> str:
-        filename = f'{include}.{self.scriptExtension}'
-        #first have a look in the package.
-        path = pkg_resources.resource_filename(__name__, f'Library/{filename}')
-        if pathlib.Path(path).is_file():
-            return path
+        filename = f'{include}{self.scriptExtension}'
+        path = os.path.join(os.path.dirname(__file__), "Library", filename)
+        if pathlib.Path(path).is_file(): return path
         path = os.path.join(scope.includeFolder, filename)
-        if pathlib.Path(path).is_file():
-            return path
+        if pathlib.Path(path).is_file(): return path
         path = os.path.join(pathlib.Path(self.filePath).parent, filename)
-        if pathlib.Path(path).is_file():
-            return path
-        return None
+        if pathlib.Path(path).is_file(): return path
+        return ''
 
 
 
@@ -90,25 +81,25 @@ class Macal:
         (r, _) = incl.Run(filename)
         if r:
             scope.Includes.append(iscope)
-        return (r, None)
+        return (r, '')
 
 
 
     def Include(self, include: str, scope: mscope.Scope) -> typing.Tuple[bool, str]:
         iscope = scope.CreateTempScope(include)
         iscope.Root = iscope  # we are our own root
-        iscope.Parent = None
+        iscope.Parent = None   # type: ignore
         iscope.Name = include # overwrite the name! We don't want it to be called as a regular child scope
         filename = self.FindIncludeFileName(include, scope)
         debug = True
-        if filename is None:
+        if filename == '':
             return (False, f'File not found ({include}).')
         if debug:
             return self.RunInclude(filename, scope, iscope)
         try:
             return self.RunInclude(filename, scope, iscope)
         except Exception as ex:
-            return (False, ex)
+            return (False, f"{ex}")
         
 
 
@@ -117,7 +108,6 @@ class Macal:
         lex = lexer.Lexer()
         root.Tokens = lex.Lex(root.Source, filename)
         parse = parser.Parser()
-        parse.Debug = self.debugParser
         root.AST = parse.Parse(root.Tokens, filename)
         intrprt = interpreter.Interpreter(self.Include)
         exitcode.SetValue(0)
@@ -128,9 +118,8 @@ class Macal:
     def Run(self, filename: str)-> typing.Tuple[bool, mscope.Scope]:
         self.filePath = filename
         source = self.LoadFile(filename)
-        if source is None:
-            print("Failed to load file (", filename, ").")
-            return (False, None)
+        if source == '':
+            raise exceptions.RuntimeError(f"Failed to load file {filename}", None, filename)           
         if self.debug:
             return self.Execute(source, filename, self.Root, self.exitcode)
         try:
@@ -144,8 +133,7 @@ class Macal:
         except exceptions.RuntimeError as ex:
             self.exitcode.SetValue(3)
             print(ex)
+        except Exception as ex:
+            self.exitcode.SetValue(4)
+            print(f'Unhandled exception: {ex}')
         return (False, self.Root)
-
-
-
-
