@@ -6,21 +6,20 @@
 
 from __future__ import annotations
 import typing
-from . import types
-from . import exceptions
 from . import variable
 from . import ast
 from . import token
 from . import ast_function_definition
 
+__nil_scope__ = None
 
 class Scope:
-    def __init__(self, name: str) -> Scope:
+    def __init__(self, name: str) -> None:
         self.Name: str = name
-        self.Parent = None
-        self.Root = None
-        self.Variables: typing.List[variable.Variable] = []
-        self.Functions: typing.List[ast_function_definition.FunctionDefinition] = []
+        self.Parent: typing.Optional[Scope] = None
+        self.Root: Scope = self
+        self.Variables: typing.Dict[str, variable.Variable] = {}
+        self.Functions: typing.Dict[str, ast_function_definition.FunctionDefinition] = {}
         self.Includes: typing.List[Scope] = []
         self.includeFolder: str = '/Library'
         self.externFolder: str = '/Library/Extern'
@@ -31,13 +30,13 @@ class Scope:
         self.Halt: bool = False
         self.Continue: bool = False
         self.Return: bool = False
-        self.Source: str = None
-        self.Tokens: typing.List[token.LexToken] = None
-        self.AST: typing.List[ast.AST] = None
+        self.Source: str = ''
+        self.Tokens: typing.List[token.LexToken] = []
+        self.AST: typing.List[ast.AST] = []
         self.iter = 0
-        self.RunFunction: typing.Callable = None
-
+        self.RunFunction: typing.Callable = None # type: ignore
 
+    
 
     def CreateTempScope(self, name: str) -> Scope:
         name = f'{self.Name}{name}'
@@ -56,22 +55,21 @@ class Scope:
             if include.Name == name:
                 return include
         if self.Parent != None:
-            return self.Parent.findInclude(name)
-        return None
+            return self.Parent.FindInclude(name)
+        return None # type: ignore
 
 
 
     def FindFunction(self, name: str, scope: Scope) -> ast_function_definition.FunctionDefinition:
-        for fn in scope.Functions:
-            if fn.Name == name:
-                return fn
+        if name in scope.Functions:
+            return scope.Functions[name]
         for incl in scope.Includes:
             fn = incl.FindFunction(name, incl)
             if fn is not None:
                 return fn
         if scope.Parent is not None:
             return self.FindFunction(name, scope.Parent)
-        return None
+        return None # type: ignore
 
 
 
@@ -82,28 +80,27 @@ class Scope:
 
 
     def AddVariable(self, var: variable.Variable):
-        self.Variables.append(var)
+        self.Variables[var.Name] = var
 
 
     
     def GetVariable(self, name: str) -> variable.Variable:
-        for var in self.Variables:
-            if var.Name == name:
-                return var
-        return None
+        if name in self.Variables:
+            return self.Variables[name]
+        return None # type: ignore
 
 
 
-    def FindVariableInIncludes(self, name: str) -> variable.Variable:
+    def FindVariableInIncludes(self, name: str) -> typing.Optional[variable.Variable]:
         for incl in self.Includes:
             var = incl.FindVariable(name)
             if var is not None: return var
         if self.Parent is not None:
             return self.Parent.FindVariableInIncludes(name)
+        return None
 
 
-
-    def FindVariable(self, name: str) -> variable.Variable:
+    def FindVariable(self, name: str) -> typing.Optional[variable.Variable]:
         var = self.GetVariable(name)
         if var is None:
             var = self.FindVariableInIncludes(name)
@@ -115,13 +112,13 @@ class Scope:
 
     def CreateAndAppendFunctionReturnVariable(self, tok: token.LexToken) -> variable.Variable:
         returnVar = self.NewVariable(tok, f'?return_var{self.Name}')
-        self.Variables.append(returnVar)
+        self.Variables[returnVar.Name] = returnVar
         return returnVar
 
 
 
     def GetFunctionReturnVariable(self) -> variable.Variable:
-        return self.GetVariable(f'?return_var{self.Name}')
+        return self.Variables[f'?return_var{self.Name}']
 
 
 
@@ -137,6 +134,14 @@ class Scope:
             self.Parent.SetHalt(value)
 
 
+    def SetReturn(self, value: bool) -> None:
+        self.Return = value
+        if (self.Parent is not None and self.Parent.isFunction):
+            self.Parent.SetReturn(value)
+
 
     def __repr__(self) -> str:
-        return f'Scope(Name="{self.Name}");'
\ No newline at end of file
+        return f'Scope(Name="{self.Name}");'
+
+
+__nil_scope__ = Scope('')
\ No newline at end of file
