@@ -5,33 +5,27 @@
 #
 
 
-
+from __future__ import annotations
+import typing
 import copy
+from dataclasses import dataclass
 from . import types
 from . import location
 
 
-
+@dataclass
 class LexToken:
-    """Lexer token"""
-    def __init__(self, lexeme: str, type: types.LexTokenType, loc: location.SourceLocation, index: int):
-        self.Lexeme:   str = lexeme
-        self.Type:     types.LexTokenType = type
-        self.Location: location.SourceLocation = loc
-        self.Start:    int = index
-
-
-
-    def __repr__(self):
-        s = self.Lexeme
-        if isinstance(self.Lexeme, str):
-            s = s.replace('\n','')
-            s = s.replace('\t', '    ')
-        return f"LexToken(Lexeme='{s}', Type='{self.Type}', Location={self.Location}, Start = {self.Start}"
+    Lexeme:   str
+    Type:     types.LexTokenType
+    Location: typing.Optional[location.SourceLocation]
+    Start:    int
+    Filename: str
 
 
 
     def __str__(self):
+        if self.Start == -1:
+            return ''
         s = self.Lexeme
         if isinstance(self.Lexeme, str):
             s = s.replace('\n','')
@@ -46,6 +40,3 @@ class LexToken:
     def Clone(self):
         return copy.deepcopy(self)
     
-    @staticmethod
-    def nullToken():
-        return LexToken("Nil", types.LexTokenTypes.Nil, location.nullLoc(), -1)
\ No newline at end of file
